From ef55b578effea959ed4fdcdb0fd4bbab38209fef Mon Sep 17 00:00:00 2001
From: ftimme <ft@falkotimme.com>
Date: Thu, 06 Sep 2012 11:21:32 -0400
Subject: [PATCH] - New feature: you can now add directive snippets for Apache, nginx, and PHP under System > Directive Snippets. These snippets are then available on the Options tab of a web site where they can be easily added to the respective textarea by simply clicking the name of the directive snippet.

---
 interface/web/admin/server_ip_list.php |   10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/interface/web/admin/server_ip_list.php b/interface/web/admin/server_ip_list.php
index f701953..6c98269 100644
--- a/interface/web/admin/server_ip_list.php
+++ b/interface/web/admin/server_ip_list.php
@@ -41,13 +41,13 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'admin')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('admin');
 
 $app->uses('listform_actions');
+
+$app->listform_actions->SQLOrderBy = "ORDER BY server_id, ip_address";
+
 $app->listform_actions->onLoad();
 
 

--
Gitblit v1.9.1